@@ -6,13 +6,17 @@ This file is part of minos framework.
 Minos framework can not be copied and/or distributed without the express permission of Clariteia SL.
 """
 
-__version__ = "0.0.3"
+__version__ = "0.0.4"
 
+from .broker import (
+    Command,
+    Event,
+    MinosBaseBroker,
+)
 from .configuration import (
     BROKER,
     COMMAND,
     COMMANDS,
-    DATABASE,
     ENDPOINT,
     EVENT,
     EVENTS,
@@ -103,6 +107,9 @@ from .repository import (
     MinosRepositoryEntry,
     PostgreSqlMinosRepository,
 )
+from .setup import (
+    MinosSetup,
+)
 from .storage import (
     MinosStorage,
     MinosStorageLmdb,
